==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/MOBILENOTEBOOKREFERENCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MOBILENOTEBOOKREFERENCEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MOBILENOTEBOOKREFERENCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILENOTEBOOKID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REFERENCEDMOBILENOTEBOOKID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MOBILENOTEBOOKREFERENCEID_Type", propOrder = {
    "mobilenotebookid",
    "referencedmobilenotebookid"
})
public class MOBILENOTEBOOKREFERENCEID_Type {

    @XmlElement(name = "MOBILENOTEBOOKID")
    protected STANDARDENTITYID_Type mobilenotebookid;
    @XmlElement(name = "REFERENCEDMOBILENOTEBOOKID")
    protected STANDARDENTITYID_Type referencedmobilenotebookid;

    /**
     * Gets the value of the mobilenotebookid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getMOBILENOTEBOOKID() {
        return mobilenotebookid;
    }

    /**
     * Sets the value of the mobilenotebookid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setMOBILENOTEBOOKID(STANDARDENTITYID_Type value) {
        this.mobilenotebookid = value;
    }

    /**
     * Gets the value of the referencedmobilenotebookid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getREFERENCEDMOBILENOTEBOOKID() {
        return referencedmobilenotebookid;
    }

    /**
     * Sets the value of the referencedmobilenotebookid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setREFERENCEDMOBILENOTEBOOKID(STANDARDENTITYID_Type value) {
        this.referencedmobilenotebookid = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/MOBILENOTEBOOKREFERENCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour MOBILENOTEBOOKREFERENCEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="MOBILENOTEBOOKREFERENCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILENOTEBOOKID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REFERENCEDMOBILENOTEBOOKID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MOBILENOTEBOOKREFERENCEID_Type", propOrder = {
    "mobilenotebookid",
    "referencedmobilenotebookid"
})
public class MOBILENOTEBOOKREFERENCEID_Type {

    @XmlElement(name = "MOBILENOTEBOOKID")
    protected STANDARDENTITYID_Type mobilenotebookid;
    @XmlElement(name = "REFERENCEDMOBILENOTEBOOKID")
    protected STANDARDENTITYID_Type referencedmobilenotebookid;

    /**
     * Obtient la valeur de la propriété mobilenotebookid.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getMOBILENOTEBOOKID() {
        return mobilenotebookid;
    }

    /**
     * Définit la valeur de la propriété mobilenotebookid.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setMOBILENOTEBOOKID(STANDARDENTITYID_Type value) {
        this.mobilenotebookid = value;
    }

    /**
     * Obtient la valeur de la propriété referencedmobilenotebookid.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getREFERENCEDMOBILENOTEBOOKID() {
        return referencedmobilenotebookid;
    }

    /**
     * Définit la valeur de la propriété referencedmobilenotebookid.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setREFERENCEDMOBILENOTEBOOKID(STANDARDENTITYID_Type value) {
        this.referencedmobilenotebookid = value;
    }

}
